@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 >>> d1=Duration(4, 0, Rat(1, 1))
 >>> d2=Duration(4, 1, Rat(1, 1))
 >>> d1==d2
-0
+False
 >>> d1.get_rat_value()
 (Rat 1/4)
 >>> d2.get_rat_value()
@@ -29,11 +29,11 @@
 (Rat 7/24)
 """
 if __name__ == "__main__":
-    import sys, os
-    if os.path.isdir("soundcard"):
-        sys.path.append(".")
-    else:
-        sys.path.append("..")
+    import sys
+    sys.path.append(".")
+    sys.path.append("src")
+    import i18n
+    i18n.setup_srcdir()
 
 from soundcard.rat import Rat
 
@@ -48,7 +48,7 @@ class Duration:
         >>> B=Duration(4, 1, Rat(1, 1))
         >>> C=Duration(2, 2, Rat(4, 7))
         >>> A==None, A==B, A==C
-        (0, 1, 0)
+        (False, True, False)
         >>> (cmp(A, C), cmp(A, B))
         (-1, 0)
         """
