@@ -3,6 +3,12 @@
 ss="""
 <head>
 <style type="text/css">
+/* Used for proofreading.
+.sect1 { margin-left: 1em}
+.sect2 { margin-left: 2em}
+.sect3 { margin-left: 3em}
+.sect4 { margin-left: 4em}
+*/
 h1 { font-weight: bold; font-size: 2em;    margin: 0.67em 0 0;}
 h2 { font-weight: bold; font-size: 1.5em;  margin: 0.83em 0 0;}
 h3 { font-weight: bold; font-size: 1.17em; margin: 1em 0 0;}
