@@ -30,6 +30,6 @@ class SeqNoSynthsException(SoundInitException):
     def __init__(self, dev):
         self.m_dev = dev
     def __str__(self):
-        return "SNDCTL_SEQ_NRSYNTHS report that there are not synths on %s." % self.m_dev
+        return "SNDCTL_SEQ_NRSYNTHS report that there are no synths on %s." % self.m_dev
 
 
