@@ -78,22 +78,12 @@ True
 import re
 import os, os.path, sys
 
-# It is a know fact that many windows lusers are $HOMEless
-if sys.platform == 'win32':
-    if not os.path.exists(os.path.expanduser("~")):
-        os.makedirs(os.path.expanduser("~"))
-
 section_re = re.compile("^\[([\w-]*?)\]")
 value_re = re.compile(  "^([\w-]*?)=(.*)")
 comment_re = re.compile("#.*")
 
-# FIXME why did I comment out the lines below. Test in ms windows
-# if this still works, and if so, delete the commented lines.
 def split(key):
-   #if "/" in key:
-       return key.split("/")
-   #else:
-   #    return key.split("\\")
+    return key.split("/")
 
 def parse_file_into_dict(dictionary, filename):
     f = file(filename, "r")
@@ -115,8 +105,8 @@ def parse_file_into_dict(dictionary, filename):
         elif line == "\n":
             pass
         else:
-           print filename
-           raise Exception("Shit happended line %s" % line)
+            print filename
+            raise Exception("Shit happended line %s" % line)
         line = f.readline()
     f.close()
     return dictionary
@@ -199,29 +189,29 @@ def get_string(key):
         return default
 
 def get_int(key):
-   if len(key.split("=")) == 2:
-      key, default = key.split("=")
-   else:
-      default = 0
-   section, k = split(key)
-   try:
-       # UGH win32 fix
-       if not data[section][k]:
-           return 0
-       return int(float(data[section][k]))
-   except KeyError:
-       return int(default)
+    if len(key.split("=")) == 2:
+        key, default = key.split("=")
+    else:
+        default = 0
+    section, k = split(key)
+    try:
+        # UGH win32 fix
+        if not data[section][k]:
+            return 0
+        return int(float(data[section][k]))
+    except KeyError:
+        return int(default)
 
 def get_float(key):
-   if len(key.split("=")) == 2:
-      key, default = key.split("=")
-   else:
-      default = 0
-   section, k = split(key)
-   try:
-       return float(data[section][k])
-   except KeyError:
-       return float(default)
+    if len(key.split("=")) == 2:
+        key, default = key.split("=")
+    else:
+        default = 0
+    section, k = split(key)
+    try:
+        return float(data[section][k])
+    except KeyError:
+        return float(default)
 
 def get_list(key):
     if len(key.split("=")) == 2:
@@ -273,14 +263,16 @@ def dump(dict, fn):
 
 def drop_user_config():
     """
-    Reread the config data, but only read the systems defaults, not
-    .solfegerc in the users $HOME.
+    Reread the config data, but only read the systems defaults from
+    /usr/share/solfege/default.config and /etc/solfege, not
+    $HOME/.solfegerc
     """
     global data, _watches, _watch_counter, _blocked_watches
     data = {}
     _watches = {}
     _watch_counter = 0
     _blocked_watches = {}
+    data = parse_file_info_dict(data, _app_defaults_filename)
     data = parse_file_into_dict(data, _system_filename)
 
 def reread_data():
@@ -400,7 +392,7 @@ class ConfigUtils(object):
         return self._get(get_bool, name)
     def get_list(self, name):
         if '=' in name:
-           return eval(self._get(get_string, name))
+            return eval(self._get(get_string, name))
         return eval(self._get(get_string, name, "=[]"))
 
 
