@@ -4,8 +4,8 @@
 
 def register_exercise(d):
     global __exdata__
-    if not d.has_key('exercise_pretty_name'):
+    if 'exercise_pretty_name' not in d:
         d['exercise_pretty_name'] = d['menu_path'].split('/')[1].replace('_', '')
-    if not d.has_key('exercise_config'):
+    if 'exercise_config' not in d:
         d['exercise_config'] = ''
     __exdata__.append(d)
