@@ -24,7 +24,7 @@ __exercise_data__ = {
 import exercise_setup
 exercise_setup.register_exercise(__exercise_data__)
 
-import gtk, gnome
+import gtk, gnome, gobject
 import gu, widgets, inputwidgets
 import soundcard, mpd
 import abstract, const, utils
@@ -49,7 +49,7 @@ class Teacher(abstract.Teacher):
         ERR_PICKY: you have to solve this question before you are allowed to create new
         """
         if self.m_timeout_handle:
-            gtk.timeout_remove(self.m_timeout_handle)
+            gobject.source_remove(self.m_timeout_handle)
             self.m_timeout_handle = None
 
         if self.get_bool('config/picky_on_new_question') \
@@ -303,7 +303,7 @@ class Gui(abstract.IntervalGui):
     def on_start_practise(self):
         self.m_t.m_statistics.reset_session()
         self.g_new_interval.grab_focus()
-        gtk.timeout_add(const.SHORT_WAIT, lambda self=self:
+        gobject.timeout_add(const.SHORT_WAIT, lambda self=self:
             self.g_flashbar.flash(_("Click 'New interval' to begin.")))
     def on_end_practise(self):
         self.m_t.end_practise()
