@@ -18,7 +18,7 @@
 __exercise_data__ = {
     'exercise_name': 'harmonic-progression-dictation',
     'menu_path': '%s/%s' % (_("_Misc exercises"), _("Harmonic _progression dictation")),
-    'icon': 'graphics/harmonicprogression24.png',
+    'stock-icon': 'solfege-harmonic-progression-dictation',
     'toolbar': 13,
 }
 import exercise_setup
@@ -48,7 +48,6 @@ class Gui(abstract.LessonbasedGui):
         # practise_box #
         ################
         self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer(utils.play_tone)
-        self.g_music_displayer.set_size_request(-1, 170)
         self.practise_box.pack_start(self.g_music_displayer)
 
         self.g_flashbar = gu.FlashBar()
@@ -120,7 +119,7 @@ class Gui(abstract.LessonbasedGui):
             self.g_show.set_sensitive(False)
             self.g_guess_answer.set_sensitive(False)
             self.g_entry.set_text("")
-            self.g_music_displayer.clear()
+            self.g_music_displayer.clear(2)
         if not self.m_t.m_P:
             return
         # pop just in case there is something in the stack.
@@ -161,10 +160,10 @@ class Gui(abstract.LessonbasedGui):
         self.g_repeat.set_sensitive(False)
         self.g_guess_answer.set_sensitive(False)
         self.g_show.set_sensitive(False)
-        self.g_music_displayer.clear()
+        self.g_music_displayer.clear(2)
         self.m_t.end_practise()
     def update_gui_after_lessonfile_change(self):
-        self.g_music_displayer.clear()
+        self.g_music_displayer.clear(2)
         if self.m_t.m_P:
             self.g_random_transpose.set_text(str(self.m_t.m_P.header.random_transpose))
             self.g_new.set_sensitive(True)
