@@ -143,9 +143,8 @@ class HTMLWriter(formatter.NullWriter):
         if self.m_ignore_flowing_data:
             return
         buf = self.g_tw.get_buffer()
-        # FIXME the whole charset/unicode stuff need revision
-        if self.m_charset == "UTF-8":
-            txt = unicode(txt, self.m_charset, 'replace')
+        if not isinstance(txt, unicode):
+            txt = txt.decode(self.m_charset, 'replace')
         txt = txt.strip('\n')
         tags = ['normal', '%s-margin%i' % self.m_margin]
         if self.m_link:
@@ -249,6 +248,10 @@ class HTMLWriter(formatter.NullWriter):
             t = b.create_tag('ul-margin%i' % n)
             t.set_property('left-margin', n*20+10)
 
+        for n in range(10):#FIXME numeric constant
+            t = b.create_tag('ol-margin%i' % n)
+            t.set_property('left-margin', n*20+10)
+
 
 class MyHTMLParser(htmllib.HTMLParser):
     def __init__(self, formatter, writer):
