@@ -37,7 +37,7 @@ def _i(s):
 def langs():
     ret = []
     for k in ('LANGUAGE', 'LC_ALL', 'LC_MESSAGES', 'LANG'):
-        if os.environ.has_key(k):
+        if k in os.environ:
             v = os.environ.get(k)
             if v:
                 ret = v.split(':')
