@@ -17,7 +17,7 @@
 
 __exercise_data__ = {
     'exercise_name': 'identify-bpm',
-    'menu_path': '%s/%s' % (_("_Rhythm"), _("Bpm")),
+    'menu_path': '%s/%s' % (_("_Rhythm"), _("_Bpm")),
     'stock-icon': 'solfege-identify-bpm',
     'toolbar': 12,
 }
@@ -142,7 +142,7 @@ class Gui(abstract.Gui):
         ##############
         # statistics #
         ##############
-        self.g_statview = statisticsviewer.StatisticsViewer(self.m_t.m_statistics, 'Bpm')
+        self.g_statview = statisticsviewer.StatisticsViewer(self.m_t.m_statistics, _('Bpm'))
         self.g_statview.show()
         self.g_notebook.append_page(self.g_statview,
                                     gtk.Label(_("Statistics")))
