@@ -15,6 +15,8 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+from __future__ import generators
+
 try:
     app_running == True
 except:
@@ -347,7 +349,7 @@ class LessonfileCommon(object):
             rel_note = m.group('note')
             nn = mpd.MusicalPitch.new_from_notename(rel_note)
             aa = m.group('pre') + nn.get_octave_notename()
-            v[i] = m.group('pre') + nn.get_notename() + v[i][len(aa)::]
+            v[i] = m.group('pre') + nn.get_notename() + v[i][len(aa):]
             return r"\staff\transpose %s\relative %s{ %s }" \
               % (self.m_transpose.get_octave_notename(), 
                  rel_note, " ".join(v))
@@ -457,7 +459,7 @@ class LessonfileCommon(object):
                 question[varname].m_musicdata))
         elif question[varname].m_musictype in ('normal', 'satb', 'voice', 'rvoice'):
             self.play_question_musicformat_normal_satb(question)
-        elif question[varname].m_musictype in 'chord':
+        elif question[varname].m_musictype == 'chord':
             self.play_question_musicformat_chord(question)
         else:
             raise LessonfileException("Unrecognised musictype '%s'" % question[varname].m_musictype)
@@ -477,7 +479,7 @@ class LessonfileCommon(object):
         bpm = (bpm[0]/2, bpm[1])
         mpd.play_music(question.get_music(), bpm,
                        instrument[0], instrument[1])
-    def play_question_musicformat_chord(self, question):
+    def play_question_musicformat_chord(self, question, varname='music'):
         assert question['music'].m_musictype == 'chord'
         instrument = self.prepare_instrument_list(question)
         assert len(instrument) in (2, 6)
@@ -592,7 +594,14 @@ class LessonfileCommon(object):
         Use app default values if the variable is missing.
         Convert instrument names to integer values.
         """
-        if 'instrument' in question:
+        if self.m_t.get_bool('override_default_instrument'):
+            instrument = [self.m_t.get_int('highest_instrument'),
+                         self.m_t.get_int('highest_instrument_velocity'),
+                         self.m_t.get_int('middle_instrument'),
+                         self.m_t.get_int('middle_instrument_velocity'),
+                         self.m_t.get_int('lowest_instrument'),
+                         self.m_t.get_int('lowest_instrument_velocity')]
+        elif 'instrument' in question:
             instrument = question['instrument']
         elif 'instrument' in self.m_globals:
             instrument = self.m_globals['instrument']
