@@ -194,8 +194,7 @@ import melodicinterval, chord, rhythm
 import chordvoicing, harmonicinterval, \
        singinterval, idbyname, dictation, twelvetone, \
        idtone, compareintervals, singchord, identifybpm, \
-       harmonicprogressiondictation, singanswer,\
-       polyrhythm, intervals
+       harmonicprogressiondictation, singanswer
 
 import exercise_setup
 exercise_setup.register_exercise({
@@ -517,15 +516,15 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
         menuitem = gtk.MenuItem(_("_Theory"))
         menu.add(menuitem)
         menuitem.set_submenu(self.create_ex_menu(
-              ( ('_Scale names', 'theory-scales.html'),
-                ('_Intervals', 'theory-intervals.html'),
+              ( #(_('_Scale names'), 'theory-scales.html'),
+                (_('_Intervals'), 'theory-intervals.html'),
                ), ag))
         item = gtk.MenuItem()
         item.add(gtk.HSeparator())
         menu.add(item)
         ##############
         # Preferences
-        menu.add(gu.create_stock_menu_item('gtk-preferences', _("Preferences window"), self.open_preferences_window, ag, gtk.keysyms.F12, gtk.gdk.CONTROL_MASK))
+        menu.add(gu.create_stock_menu_item('gtk-preferences', _("_Preferences"), self.open_preferences_window, ag, gtk.keysyms.F12, gtk.gdk.CONTROL_MASK))
         #######
         # Exit
         menu.add(gu.create_stock_menu_item('gtk-quit', _("_Exit"), self.quit_program, ag, gtk.keysyms.Q, gtk.gdk.CONTROL_MASK))
