@@ -153,10 +153,21 @@ class nNotenameRangeController(NotenameRangeController, cfg.ConfigUtils):
         cfg.ConfigUtils.__init__(self, exname)
         self.m_name_low = name_low
         self.m_name_high = name_high
-        self.g_spin_low.set_value(mpd.notename_to_int(self.get_string(self.m_name_low)))
-        self.g_spin_high.set_value(mpd.notename_to_int(self.get_string(self.m_name_high)))
+        low = mpd.notename_to_int(self.get_string(self.m_name_low))
+        high = mpd.notename_to_int(self.get_string(self.m_name_high))
+        if low > high:
+            low = high
+        self.g_spin_low.set_value(low)
+        self.g_spin_high.set_value(high)
+    def on_low_changed(self, w, v):
+        NotenameRangeController.on_low_changed(self, w, v)
+        self.set_string(self.m_name_low, mpd.int_to_notename(self.g_spin_low.get_value()))
+    def on_high_changed(self, w, v):
+        NotenameRangeController.on_high_changed(self, w, v)
+        self.set_string(self.m_name_high, mpd.int_to_notename(self.g_spin_high.get_value()))
     def set_range(self, lowest_value, highest_value):
         """
+        Set the lowest and highest tone allowed.
         make a separate function for NotenameRangeController if we need it.
         """
         assert mpd.compare_notenames(lowest_value, highest_value) <= 0
