@@ -18,7 +18,7 @@
 __exercise_data__ = {
     'exercise_name': 'sing-interval',
     'menu_path': '%s/%s' % (_("_Intervals"), _("_Sing interval")),
-    'icon': 'graphics/singinterval24.png',
+    'stock-icon': 'solfege-sing-interval',
     'toolbar': 4,
 }
 import exercise_setup
